@@ -2,6 +2,7 @@
  * mate-panel-applet-gsettings.c: panel applet preferences handling.
  *
  * Copyright (C) 2012 Stefano Karapetsas
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -34,7 +35,7 @@ mate_panel_applet_settings_new (MatePanelApplet *applet, gchar *schema)
     GSettings *settings = NULL;
     gchar *path;
 
-    g_return_val_if_fail (PANEL_IS_APPLET (applet), NULL);
+    g_return_val_if_fail (MATE_PANEL_IS_APPLET (applet), NULL);
 
     path = mate_panel_applet_get_preferences_path (applet);
 
