@@ -1,6 +1,7 @@
 /*
  * MATE panel launcher module.
  * (C) 1997 The Free Software Foundation
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Authors: Miguel de Icaza
  *          Federico Mena
@@ -25,6 +26,7 @@ typedef struct {
 	char              *location;
 	GKeyFile          *key_file;
 
+	GFileMonitor      *monitor;
 	GtkWidget         *prop_dialog;
 	GSList            *error_dialogs;
 
@@ -48,8 +50,8 @@ void panel_launcher_create_from_info (PanelToplevel *toplevel,
 				      const char    *comment,
 				      const char    *icon);
 
-void		launcher_launch    		(Launcher  *launcher,
-						 GtkWidget *widget);
+void		launcher_launch			(Launcher  *launcher,
+						 const gchar *action);
 
 void		launcher_properties		(Launcher  *launcher);
 
@@ -72,7 +74,6 @@ void            launcher_properties_destroy     (Launcher *launcher);
 void            panel_launcher_set_dnd_enabled  (Launcher *launcher,
 						 gboolean  dnd_enabled);
 
-
 #ifdef __cplusplus
 }
 #endif
