@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2010 Carlos Garcia Campos <carlosgc@gnome.org>
  * Copyright (C) 2010 Vincent Untz <vuntz@gnome.org>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,10 +33,10 @@
 #include "panel-applets-manager-dbus.h"
 
 #ifdef HAVE_X11
-#include "gdk/gdkx.h"
+#include <gdk/gdkx.h>
 #endif
 #ifdef HAVE_WAYLAND
-#include "gdk/gdkwayland.h"
+#include <gdk/gdkwayland.h>
 #endif
 
 struct _MatePanelAppletsManagerDBusPrivate
@@ -83,10 +84,7 @@ mate_panel_applet_factory_info_free (MatePanelAppletFactoryInfo *info)
 
 	g_free (info->id);
 	g_free (info->location);
-	g_list_foreach (info->applet_list,
-			(GFunc) mate_panel_applet_info_free,
-			NULL);
-	g_list_free (info->applet_list);
+	g_list_free_full (info->applet_list, mate_panel_applet_info_free);
 	info->applet_list = NULL;
 	g_free (info->srcdir);
 
@@ -121,7 +119,7 @@ _mate_panel_applets_manager_get_applet_info (GKeyFile    *applet_file,
 	supported_platforms = g_key_file_get_string_list (applet_file, group,
 							  "Platforms", NULL, NULL);
 	if (supported_platforms == NULL) {
-		// If supported platforms are not specified, assume all are supported
+		/* If supported platforms are not specified, assume all are supported */
 		x11_supported = TRUE;
 		wayland_supported = TRUE;
 	} else {
@@ -164,7 +162,7 @@ mate_panel_applets_manager_get_applet_factory_info_from_file (const gchar *filen
 	const char             *lib_prefix;
 	gchar                 **groups;
 	gsize                   n_groups;
-	gint                    i;
+	gsize                   i;
 	GError                 *error = NULL;
 
 	applet_file = g_key_file_new ();
@@ -325,8 +323,7 @@ applets_directory_changed (GFileMonitor     *monitor,
 			}
 		}
 
-		g_slist_foreach (dirs, (GFunc) g_free, NULL);
-		g_slist_free (dirs);
+		g_slist_free_full (dirs, g_free);
 	}
 		break;
 	default:
@@ -651,8 +648,7 @@ mate_panel_applets_manager_dbus_finalize (GObject *object)
 	MatePanelAppletsManagerDBus *manager = MATE_PANEL_APPLETS_MANAGER_DBUS (object);
 
 	if (manager->priv->monitors) {
-		g_list_foreach (manager->priv->monitors, (GFunc) g_object_unref, NULL);
-		g_list_free (manager->priv->monitors);
+		g_list_free_full (manager->priv->monitors, g_object_unref);
 		manager->priv->monitors = NULL;
 	}
 
