@@ -1,6 +1,7 @@
 /* Mate panel: Initialization routines
  * (C) 1997,1998,1999,2000 the Free Software Foundation
  * (C) 2000 Eazel, Inc.
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Authors: Federico Mena
  *          Miguel de Icaza
@@ -58,7 +59,7 @@ static const GOptionEntry options[] = {
   { "run-dialog", 0, 0, G_OPTION_ARG_NONE, &run_dialog, N_("Execute the run dialog"), NULL },
   /* default panels layout */
   { "layout", 0, 0, G_OPTION_ARG_STRING, &layout, N_("Set the default panel layout"), NULL },
-  { NULL }
+  { NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
 };
 
 static void
@@ -104,6 +105,14 @@ main (int argc, char **argv)
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
+	#if defined(HAVE_X11) && defined(HAVE_WAYLAND)
+		gdk_set_allowed_backends ("wayland,x11");
+	#elif defined(HAVE_WAYLAND)
+		gdk_set_allowed_backends ("wayland");
+	#else
+		gdk_set_allowed_backends ("x11");
+	#endif
+
 	gtk_init (&argc, &argv);
 
 	error = NULL;
@@ -183,25 +192,12 @@ main (int argc, char **argv)
 	                 (GFunc)panel_widget_add_forbidden,
 	                 NULL);
 
-	gboolean found_backend = FALSE;
-
-#ifdef HAVE_WAYLAND
-	if (GDK_IS_WAYLAND_DISPLAY (display)) {
-		found_backend = TRUE;
-	}
-#endif
-
 #ifdef HAVE_X11
 	if (GDK_IS_X11_DISPLAY (display)) {
 		xstuff_init ();
-		found_backend = TRUE;
 	}
 #endif
 
-	if (!found_backend) {
-		g_error("GDK platform not supported");
-	}
-
 	/* Flush to make sure our struts are seen by everyone starting
 	 * immediate after (eg, the caja desktop). */
 	gdk_display_flush (display);
