@@ -2,6 +2,7 @@
  * panel-addto.h:
  *
  * Copyright (C) 2004 Vincent Untz
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,6 +26,9 @@
 #ifndef __PANEL_ADDTO_H__
 #define __PANEL_ADDTO_H__
 
+#include <gtk/gtk.h>
+#include "panel-widget.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif
