@@ -372,8 +372,7 @@ panel_ditem_editor_dispose (GObject *object)
 		g_key_file_free (dialog->priv->revert_key_file);
 	dialog->priv->revert_key_file = NULL;
 
-	g_free (dialog->priv->uri);
-	dialog->priv->uri = NULL;
+	g_clear_pointer (&dialog->priv->uri, g_free);
 
 	G_OBJECT_CLASS (panel_ditem_editor_parent_class)->dispose (object);
 }
@@ -428,7 +427,7 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *klass)
 			      G_TYPE_STRING);
 
 	ditem_edit_signals[COMMAND_CHANGED] =
-		g_signal_new ("command_changed",
+		g_signal_new ("command-changed",
 			      G_TYPE_FROM_CLASS (gobject_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PanelDItemEditorClass,
@@ -464,7 +463,7 @@ panel_ditem_editor_class_init (PanelDItemEditorClass *klass)
 			      G_TYPE_STRING);
 
 	ditem_edit_signals[ERROR_REPORTED] =
-		g_signal_new ("error_reported",
+		g_signal_new ("error-reported",
 			      G_TYPE_FROM_CLASS (gobject_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (PanelDItemEditorClass,
@@ -901,10 +900,10 @@ panel_ditem_editor_connect_signals (PanelDItemEditor *dialog)
 	priv = dialog->priv;
 
 #define CONNECT_CHANGED(widget, callback) \
-	g_signal_connect_swapped (G_OBJECT (widget), "changed", \
+	g_signal_connect_swapped (widget, "changed", \
 				  G_CALLBACK (callback), \
 				  dialog); \
-	g_signal_connect_swapped (G_OBJECT (widget), "changed", \
+	g_signal_connect_swapped (widget, "changed", \
 				  G_CALLBACK (panel_ditem_editor_changed), \
 				  dialog);
 
@@ -1138,7 +1137,6 @@ panel_ditem_editor_sync_display (PanelDItemEditor *dialog)
 	                    buffer ? buffer : "");
 	g_free (buffer);
 
-
 	/* Icon */
 	buffer = panel_key_file_get_locale_string (key_file, "Icon");
 	setup_icon_chooser (dialog, buffer);
@@ -1310,7 +1308,7 @@ response_cb (GtkDialog *dialog,
 static void
 panel_ditem_editor_revert (PanelDItemEditor *dialog)
 {
-	int       i;
+	gsize     i;
 	char     *string;
 	gboolean  boolean;
 	GKeyFile *key_file;
@@ -1386,7 +1384,7 @@ panel_ditem_editor_revert (PanelDItemEditor *dialog)
 static void
 panel_ditem_editor_set_revert (PanelDItemEditor *dialog)
 {
-	int       i;
+	gsize     i;
 	char     *string;
 	gboolean  boolean;
 	GKeyFile *key_file;
