@@ -60,6 +60,12 @@ typedef enum {
 	PANEL_OBJECT_SEPARATOR,
 } PanelObjectType;
 
+typedef enum {
+	PANEL_EDGE_START  = 0,
+	PANEL_EDGE_CENTER = 1,
+	PANEL_EDGE_END    = 2
+} PanelObjectEdgeRelativity;
+
 typedef enum {
 	PANEL_ACTION_NONE = 0,
 	PANEL_ACTION_LOCK,
