@@ -59,6 +59,7 @@
 #include "panel-schemas.h"
 
 #define MAX_BOOKMARK_ITEMS      100
+#define N_MENU_ITEM_SIGNALS       9
 
 struct _PanelPlaceMenuItemPrivate {
 	GtkWidget   *menu;
@@ -73,15 +74,7 @@ struct _PanelPlaceMenuItemPrivate {
 	GFileMonitor *bookmarks_monitor;
 
 	GVolumeMonitor *volume_monitor;
-	gulong       drive_changed_id;
-	gulong       drive_connected_id;
-	gulong       drive_disconnected_id;
-	gulong       volume_added_id;
-	gulong       volume_changed_id;
-	gulong       volume_removed_id;
-	gulong       mount_added_id;
-	gulong       mount_changed_id;
-	gulong       mount_removed_id;
+	gulong       signal_id [N_MENU_ITEM_SIGNALS];
 
 	guint        use_image : 1;
 };
@@ -251,8 +244,9 @@ panel_menu_items_append_from_desktop (GtkWidget *menu,
 			       G_CALLBACK (panel_menu_item_activate_desktop_file),
 			       g_strdup (full_path),
 			       (GClosureNotify) G_CALLBACK (g_free), 0);
-	g_signal_connect (G_OBJECT (item), "button_press_event",
-			  G_CALLBACK (menu_dummy_button_press_event), NULL);
+	g_signal_connect (item, "button-press-event",
+	                  G_CALLBACK (menu_dummy_button_press_event),
+	                  NULL);
 
 	uri = g_filename_to_uri (full_path, NULL, NULL);
 
@@ -300,8 +294,9 @@ panel_menu_items_append_place_item (const char *icon_name,
 	g_signal_connect_data (item, "activate", callback, user_data,
 			       (GClosureNotify) G_CALLBACK (g_free), 0);
 
-	g_signal_connect (G_OBJECT (item), "button_press_event",
-			  G_CALLBACK (menu_dummy_button_press_event), NULL);
+	g_signal_connect (item, "button-press-event",
+	                  G_CALLBACK (menu_dummy_button_press_event),
+	                  NULL);
 
 	if (g_str_has_prefix (uri, "file:")) /*Links only work for local files*/
 		setup_uri_drag (item, uri, icon_name, GDK_ACTION_LINK);
@@ -330,9 +325,11 @@ panel_menu_items_create_action_item_full (PanelActionButtonType  action_type,
 					panel_action_get_tooltip (action_type));
 
 	g_signal_connect (item, "activate",
-			  panel_action_get_invoke (action_type), NULL);
-	g_signal_connect (G_OBJECT (item), "button_press_event",
-			  G_CALLBACK (menu_dummy_button_press_event), NULL);
+			  panel_action_get_invoke (action_type),
+	                  NULL);
+	g_signal_connect (item, "button-press-event",
+	                  G_CALLBACK (menu_dummy_button_press_event),
+	                  NULL);
 	setup_internal_applet_drag (item, action_type);
 
 	return item;
@@ -615,8 +612,9 @@ panel_menu_item_append_drive (GtkWidget *menu,
 			       g_object_ref (drive),
 			       (GClosureNotify) G_CALLBACK (g_object_unref), 0);
 
-	g_signal_connect (G_OBJECT (item), "button_press_event",
-			  G_CALLBACK (menu_dummy_button_press_event), NULL);
+	g_signal_connect (item, "button-press-event",
+	                  G_CALLBACK (menu_dummy_button_press_event),
+	                  NULL);
 }
 
 typedef struct {
@@ -715,8 +713,9 @@ panel_menu_item_append_volume (GtkWidget *menu,
 			       g_object_ref (volume),
 			       (GClosureNotify) G_CALLBACK (g_object_unref), 0);
 
-	g_signal_connect (G_OBJECT (item), "button_press_event",
-			  G_CALLBACK (menu_dummy_button_press_event), NULL);
+	g_signal_connect (item, "button-press-event",
+	                  G_CALLBACK (menu_dummy_button_press_event),
+	                  NULL);
 }
 
 static void
@@ -983,7 +982,6 @@ panel_place_menu_item_append_remote_gio (PanelPlaceMenuItem *place_item,
 		}
 		g_object_unref (root);
 
-
 		add_mounts = g_slist_prepend (add_mounts, mount);
 	}
 	add_mounts = g_slist_reverse (add_mounts);
@@ -1016,7 +1014,6 @@ panel_place_menu_item_append_remote_gio (PanelPlaceMenuItem *place_item,
 	g_list_free (mounts);
 }
 
-
 static GtkWidget *
 panel_place_menu_item_create_menu (PanelPlaceMenuItem *place_item)
 {
@@ -1266,73 +1263,31 @@ static void
 panel_place_menu_item_finalize (GObject *object)
 {
 	PanelPlaceMenuItem *menuitem = (PanelPlaceMenuItem *) object;
+	guint i;
 
-	if (menuitem->priv->caja_desktop_settings) {
-		g_object_unref (menuitem->priv->caja_desktop_settings);
-		menuitem->priv->caja_desktop_settings = NULL;
-	}
-	if (menuitem->priv->caja_prefs_settings) {
-		g_object_unref (menuitem->priv->caja_prefs_settings);
-		menuitem->priv->caja_prefs_settings = NULL;
-	}
-
-	g_object_unref (menuitem->priv->menubar_settings);
-	menuitem->priv->menubar_settings = NULL;
+	g_clear_object (&menuitem->priv->caja_desktop_settings);
+	g_clear_object (&menuitem->priv->caja_prefs_settings);
+	g_clear_object (&menuitem->priv->menubar_settings);
 
 	if (menuitem->priv->bookmarks_monitor != NULL) {
 		g_file_monitor_cancel (menuitem->priv->bookmarks_monitor);
-		g_object_unref (menuitem->priv->bookmarks_monitor);
+		g_clear_object (&menuitem->priv->bookmarks_monitor);
 	}
-	menuitem->priv->bookmarks_monitor = NULL;
 
-	if (menuitem->priv->drive_changed_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->drive_changed_id);
-	menuitem->priv->drive_changed_id = 0;
+	for (i = 0; i < N_MENU_ITEM_SIGNALS; i++) {
+#if GLIB_CHECK_VERSION(2,62,0)
+		g_clear_signal_handler (&menuitem->priv->signal_id [i],
+		                        menuitem->priv->volume_monitor);
+#else
+		if (menuitem->priv->signal_id [i] != 0) {
+			g_signal_handler_disconnect (menuitem->priv->volume_monitor,
+						     menuitem->priv->signal_id [i]);
+			menuitem->priv->signal_id [i] = 0;
+		}
+#endif
+	}
 
-	if (menuitem->priv->drive_connected_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->drive_connected_id);
-	menuitem->priv->drive_connected_id = 0;
-
-	if (menuitem->priv->drive_disconnected_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->drive_disconnected_id);
-	menuitem->priv->drive_disconnected_id = 0;
-
-	if (menuitem->priv->volume_added_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->volume_added_id);
-	menuitem->priv->volume_added_id = 0;
-
-	if (menuitem->priv->volume_changed_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->volume_changed_id);
-	menuitem->priv->volume_changed_id = 0;
-
-	if (menuitem->priv->volume_removed_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->volume_removed_id);
-	menuitem->priv->volume_removed_id = 0;
-
-	if (menuitem->priv->mount_added_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->mount_added_id);
-	menuitem->priv->mount_added_id = 0;
-
-	if (menuitem->priv->mount_changed_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->mount_changed_id);
-	menuitem->priv->mount_changed_id = 0;
-
-	if (menuitem->priv->mount_removed_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->mount_removed_id);
-	menuitem->priv->mount_removed_id = 0;
-
-	if (menuitem->priv->volume_monitor != NULL)
-		g_object_unref (menuitem->priv->volume_monitor);
-	menuitem->priv->volume_monitor = NULL;
+	g_clear_object (&menuitem->priv->volume_monitor);
 
 	G_OBJECT_CLASS (panel_place_menu_item_parent_class)->finalize (object);
 }
@@ -1354,6 +1309,7 @@ panel_place_menu_item_init (PanelPlaceMenuItem *menuitem)
 	GFile *bookmark;
 	char  *bookmarks_filename;
 	GError *error;
+	guint i;
 
 	menuitem->priv = panel_place_menu_item_get_instance_private (menuitem);
 
@@ -1408,8 +1364,7 @@ panel_place_menu_item_init (PanelPlaceMenuItem *menuitem)
 			   bookmarks_filename, error->message);
 		g_error_free (error);
 	} else {
-		g_signal_connect (G_OBJECT (menuitem->priv->bookmarks_monitor),
-				  "changed",
+		g_signal_connect (menuitem->priv->bookmarks_monitor, "changed",
 				  (GCallback) panel_place_menu_item_gtk_bookmarks_changed,
 				  menuitem);
 	}
@@ -1419,42 +1374,45 @@ panel_place_menu_item_init (PanelPlaceMenuItem *menuitem)
 
 	menuitem->priv->volume_monitor = g_volume_monitor_get ();
 
-	menuitem->priv->drive_changed_id = g_signal_connect (menuitem->priv->volume_monitor,
-							   "drive-changed",
-							   G_CALLBACK (panel_place_menu_item_drives_changed),
-							   menuitem);
-	menuitem->priv->drive_connected_id = g_signal_connect (menuitem->priv->volume_monitor,
-							     "drive-connected",
-							     G_CALLBACK (panel_place_menu_item_drives_changed),
-							     menuitem);
-	menuitem->priv->drive_disconnected_id = g_signal_connect (menuitem->priv->volume_monitor,
-							     "drive-disconnected",
-							     G_CALLBACK (panel_place_menu_item_drives_changed),
-							     menuitem);
-	menuitem->priv->volume_added_id = g_signal_connect (menuitem->priv->volume_monitor,
-							   "volume-added",
-							   G_CALLBACK (panel_place_menu_item_volumes_changed),
-							   menuitem);
-	menuitem->priv->volume_changed_id = g_signal_connect (menuitem->priv->volume_monitor,
-							     "volume-changed",
-							     G_CALLBACK (panel_place_menu_item_volumes_changed),
-							     menuitem);
-	menuitem->priv->volume_removed_id = g_signal_connect (menuitem->priv->volume_monitor,
-							     "volume-removed",
-							     G_CALLBACK (panel_place_menu_item_volumes_changed),
-							     menuitem);
-	menuitem->priv->mount_added_id = g_signal_connect (menuitem->priv->volume_monitor,
-							   "mount-added",
-							   G_CALLBACK (panel_place_menu_item_mounts_changed),
-							   menuitem);
-	menuitem->priv->mount_changed_id = g_signal_connect (menuitem->priv->volume_monitor,
-							     "mount-changed",
-							     G_CALLBACK (panel_place_menu_item_mounts_changed),
-							     menuitem);
-	menuitem->priv->mount_removed_id = g_signal_connect (menuitem->priv->volume_monitor,
-							     "mount-removed",
-							     G_CALLBACK (panel_place_menu_item_mounts_changed),
-							     menuitem);
+	i = 0;
+	menuitem->priv->signal_id [i++] =
+		g_signal_connect (menuitem->priv->volume_monitor, "drive-changed",
+		                  G_CALLBACK (panel_place_menu_item_drives_changed),
+		                  menuitem);
+	menuitem->priv->signal_id [i++] =
+		g_signal_connect (menuitem->priv->volume_monitor, "drive-connected",
+		                  G_CALLBACK (panel_place_menu_item_drives_changed),
+		                  menuitem);
+	menuitem->priv->signal_id [i++] =
+		g_signal_connect (menuitem->priv->volume_monitor, "drive-disconnected",
+		                  G_CALLBACK (panel_place_menu_item_drives_changed),
+		                  menuitem);
+	menuitem->priv->signal_id [i++] =
+		g_signal_connect (menuitem->priv->volume_monitor, "volume-added",
+		                  G_CALLBACK (panel_place_menu_item_volumes_changed),
+		                  menuitem);
+	menuitem->priv->signal_id [i++] =
+		g_signal_connect (menuitem->priv->volume_monitor, "volume-changed",
+		                  G_CALLBACK (panel_place_menu_item_volumes_changed),
+		                  menuitem);
+	menuitem->priv->signal_id [i++] =
+		g_signal_connect (menuitem->priv->volume_monitor, "volume-removed",
+		                 G_CALLBACK (panel_place_menu_item_volumes_changed),
+		                 menuitem);
+	menuitem->priv->signal_id [i++] =
+		g_signal_connect (menuitem->priv->volume_monitor, "mount-added",
+		                  G_CALLBACK (panel_place_menu_item_mounts_changed),
+		                  menuitem);
+	menuitem->priv->signal_id [i++] =
+		g_signal_connect (menuitem->priv->volume_monitor, "mount-changed",
+		                  G_CALLBACK (panel_place_menu_item_mounts_changed),
+		                  menuitem);
+	menuitem->priv->signal_id [i++] =
+		g_signal_connect (menuitem->priv->volume_monitor, "mount-removed",
+		                  G_CALLBACK (panel_place_menu_item_mounts_changed),
+		                  menuitem);
+
+	g_assert (i == N_MENU_ITEM_SIGNALS);
 
 }
 
@@ -1498,7 +1456,7 @@ GtkWidget* panel_place_menu_item_new(gboolean use_image)
 
 	setup_menuitem(GTK_WIDGET(menuitem), image ? panel_menu_icon_get_size() : GTK_ICON_SIZE_INVALID, image, _("Places"));
 
-	menuitem->priv->use_image = use_image;
+	menuitem->priv->use_image = (use_image != FALSE);
 
 	menuitem->priv->menu = panel_place_menu_item_create_menu(menuitem);
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem), menuitem->priv->menu);
@@ -1526,9 +1484,9 @@ panel_desktop_menu_item_new (gboolean use_image,
 			image,
 			_("System"));
 
-	menuitem->priv->use_image = use_image;
+	menuitem->priv->use_image = (use_image != FALSE);
 
-	menuitem->priv->append_lock_logout = append_lock_logout;
+	menuitem->priv->append_lock_logout = (append_lock_logout != FALSE);
 	if (append_lock_logout)
 		panel_lockdown_notify_add (G_CALLBACK (panel_desktop_menu_item_recreate_menu),
 					   menuitem);
