@@ -171,7 +171,7 @@ panel_properties_dialog_setup_orientation_combo (PanelPropertiesDialog *dialog,
 	GtkListStore     *model;
 	GtkTreeIter       iter;
 	GtkCellRenderer  *renderer;
-	int               i;
+	gsize             i;
 
 	dialog->orientation_combo = PANEL_GTK_BUILDER_GET (gui, "orientation_combo");
 	g_return_if_fail (dialog->orientation_combo != NULL);
@@ -356,7 +356,7 @@ panel_properties_dialog_setup_color_button (PanelPropertiesDialog *dialog,
 	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (dialog->color_button),
 	                            &color);
 
-	g_signal_connect_swapped (dialog->color_button, "color_set",
+	g_signal_connect_swapped (dialog->color_button, "color-set",
 				  G_CALLBACK (panel_properties_dialog_color_changed),
 				  dialog);
 
