@@ -41,7 +41,7 @@ static const GOptionEntry options [] = {
 	{ "prefs-path", 0, 0, G_OPTION_ARG_STRING, &cli_prefs_path, N_("Specify a gsettings path in which the applet preferences should be stored"), NULL},
 	{ "size", 0, 0, G_OPTION_ARG_STRING, &cli_size, N_("Specify the initial size of the applet (xx-small, medium, large etc.)"), NULL},
 	{ "orient", 0, 0, G_OPTION_ARG_STRING, &cli_orient, N_("Specify the initial orientation of the applet (top, bottom, left or right)"), NULL},
-	{ NULL}
+	{ NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
 };
 
 enum {
@@ -62,7 +62,6 @@ static ComboItem orient_items [] = {
 	{ NC_("Orientation", "Right"),  PANEL_ORIENTATION_RIGHT  }
 };
 
-
 static ComboItem size_items [] = {
 	{ NC_("Size", "XX Small"), 12  },
 	{ NC_("Size", "X Small"),  24  },
@@ -179,7 +178,7 @@ static void
 load_applet_from_command_line (void)
 {
 	guint size = 24, orient = PANEL_ORIENTATION_TOP;
-	gint i;
+	gsize i;
 
 	g_assert (cli_iid != NULL);
 
@@ -241,7 +240,6 @@ setup_combo (GtkWidget  *combo_box,
 	gtk_combo_box_set_model (GTK_COMBO_BOX (combo_box),
 				 GTK_TREE_MODEL (model));
 
-
 	for (i = 0; i < nb_items; i++) {
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter,
