@@ -11,7 +11,6 @@
 #ifndef PANEL_WIDGET_H
 #define PANEL_WIDGET_H
 
-
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include "button-widget.h"
@@ -192,10 +191,9 @@ void		panel_widget_draw_all		(PanelWidget *panel,
 void		panel_widget_draw_icon		(PanelWidget *panel,
 						 ButtonWidget *applet);
 
-
-/*tells us if an applet is "stuck" on the right side*/
-int		panel_widget_is_applet_stuck	(PanelWidget *panel,
-						 GtkWidget *applet);
+/*Tells us to which panel edge (start, center, end) the applet is relative*/
+PanelObjectEdgeRelativity	panel_widget_determine_applet_edge_relativity	(PanelWidget *panel,
+										 GtkWidget *applet);
 /*get pos of the cursor location in panel coordinates*/
 int		panel_widget_get_cursorloc	(PanelWidget *panel);
 
