@@ -3,6 +3,7 @@
  *
  * Copyright (C) 2000, 2001 Eazel, Inc.
  *               2002 Sun Microsystems Inc.
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Authors: George Lebl <jirka@5z.com>
  *          Mark McLoughlin <mark@skynet.ie>
@@ -12,7 +13,13 @@
  *  Copyright (c) 1997-2002 Alfredo K. Kojima
 
  */
+
 #include <config.h>
+
+#ifndef HAVE_X11
+#error file should only be built when HAVE_X11 is enabled
+#endif
+
 #include <string.h>
 #include <unistd.h>
 
@@ -40,6 +47,11 @@ static gboolean xstuff_display_is_dead = FALSE;
 #define ZOOM_STEPS  14
 #define ZOOM_DELAY 10
 
+gboolean is_using_x11 ()
+{
+	return GDK_IS_X11_DISPLAY (gdk_display_get_default ());
+}
+
 typedef struct {
 	int size;
 	int size_start;
@@ -195,8 +207,9 @@ draw_zoom_animation_composited (GdkScreen *gscreen,
 
 	gtk_window_move (GTK_WINDOW (win), wx, wy);
 
-	g_signal_connect (G_OBJECT (win), "draw",
-			 G_CALLBACK (zoom_draw), zoom);
+	g_signal_connect (win, "draw",
+	                  G_CALLBACK (zoom_draw),
+	                  zoom);
 
 	/* see doc for gtk_widget_set_app_paintable() */
 	gtk_widget_realize (win);
@@ -221,7 +234,7 @@ draw_zoom_animation (GdkScreen *gscreen,
 	int i, j;
 	GC frame_gc;
 	XGCValues gcv;
-	GdkColor color = { 65535, 65535, 65535 };
+	GdkColor color = { .pixel = 0, .red = 65535, .green = 65535, .blue = 65535 };
 	Display *dpy;
 	Window root_win;
 	int screen;
@@ -335,8 +348,6 @@ xstuff_zoom_animate (GtkWidget *widget,
 	GdkScreen *gscreen;
 	GdkRectangle rect, dest;
 	GtkAllocation allocation;
-	GdkMonitor *monitor;
-	GdkDisplay *display;
 
 	if (opt_rect)
 		rect = *opt_rect;
@@ -364,8 +375,8 @@ xstuff_zoom_animate (GtkWidget *widget,
 				pixbuf, orientation);
 		g_object_unref (pixbuf);
 	} else {
-		display = gdk_screen_get_display (gscreen);
-		monitor = gdk_display_get_monitor_at_window (display,
+		GdkDisplay *display = gdk_screen_get_display (gscreen);
+		GdkMonitor *monitor = gdk_display_get_monitor_at_window (display,
 							     gtk_widget_get_window (widget));
 		gdk_monitor_get_geometry (monitor, &dest);
 
